@@ -25,6 +25,7 @@ use std::borrow::Cow;
 ///     channel_id: 1,
 /// }).body(body).build();
 /// ```
+#[derive(Debug)]
 pub struct RequestBuilder(Request);
 
 impl RequestBuilder {
@@ -34,6 +35,48 @@ impl RequestBuilder {
         Self(Request::from_route(route))
     }
 
+    /// Create a request with raw information about the method, ratelimiting
+    /// path, and URL path and query.
+    ///
+    /// The path and query should not include the leading slash as that is
+    /// prefixed by the client. In the URL
+    /// `https://discord.com/api/vX/channels/123/pins` the "path and query"
+    /// is considered to be `channels/123/pins`.
+    ///
+    /// # Examples
+    ///
+    /// Create a request from a method and the URL path and query
+    /// `channels/123/pins`:
+    ///
+    /// ```
+    /// # fn main() -> Result<(), Box<dyn std::error::Error>> {
+    /// use std::str::FromStr;
+    /// use twilight_http::{request::{Method, RequestBuilder}, routing::Path};
+    ///
+    /// let method = Method::Post;
+    /// let path_and_query = "channels/123/pins".to_owned();
+    /// let ratelimit_path = Path::from_str(&path_and_query)?;
+    ///
+    /// let _request = RequestBuilder::raw(
+    ///     method,
+    ///     ratelimit_path,
+    ///     path_and_query,
+    /// ).build();
+    /// # Ok(()) }
+    /// ```
+    #[must_use = "request has not been fully built"]
+    pub const fn raw(method: Method, path: Path, path_and_query: String) -> Self {
+        Self(Request {
+            body: None,
+            form: None,
+            headers: None,
+            method,
+            path,
+            path_str: Cow::Owned(path_and_query),
+            use_authorization_token: true,
+        })
+    }
+
     /// Consume the builder, returning the built request.
     #[allow(clippy::missing_const_for_fn)]
     #[must_use = "request information is not useful on its own and must be acted on"]
@@ -114,21 +157,22 @@ impl Request {
     ///
     /// Use the [`RequestBuilder`] if you need to set a combination of
     /// configurations in the request.
+    // `Route`'s methods have been changed to no longer consume itself, so we
+    // could pass the route by reference but we need to avoid breakage.
+    #[allow(clippy::needless_pass_by_value)]
     #[deprecated(since = "0.4.0", note = "Use `Request::builder` instead")]
     pub fn new(
         body: Option<Vec<u8>>,
         headers: Option<HeaderMap<HeaderValue>>,
         route: Route,
     ) -> Self {
-        let (method, path, path_str) = route.into_parts();
-
         Self {
             body,
             form: None,
             headers,
-            method,
-            path,
-            path_str,
+            method: route.method(),
+            path: route.path(),
+            path_str: Cow::Owned(route.display().to_string()),
             use_authorization_token: true,
         }
     }
@@ -175,16 +219,17 @@ impl Request {
     /// ```
     ///
     /// [`builder`]: Self::builder
+    // `Route`'s methods have been changed to no longer consume itself, so we
+    // could pass the route by reference but we need to avoid breakage.
+    #[allow(clippy::needless_pass_by_value)]
     pub fn from_route(route: Route) -> Self {
-        let (method, path, path_str) = route.into_parts();
-
         Self {
             body: None,
             form: None,
             headers: None,
-            method,
-            path,
-            path_str,
+            method: route.method(),
+            path: route.path(),
+            path_str: Cow::Owned(route.display().to_string()),
             use_authorization_token: true,
         }
     }
@@ -197,15 +242,13 @@ impl Request {
 
 impl From<Route> for Request {
     fn from(route: Route) -> Self {
-        let (method, path, path_str) = route.into_parts();
-
         Self {
             body: None,
             form: None,
             headers: None,
-            method,
-            path,
-            path_str,
+            method: route.method(),
+            path: route.path(),
+            path_str: Cow::Owned(route.display().to_string()),
             use_authorization_token: true,
         }
     }
@@ -213,15 +256,13 @@ impl From<Route> for Request {
 
 impl From<(Vec<u8>, Route)> for Request {
     fn from((body, route): (Vec<u8>, Route)) -> Self {
-        let (method, path, path_str) = route.into_parts();
-
         Self {
             body: Some(body),
             form: None,
             headers: None,
-            method,
-            path,
-            path_str,
+            method: route.method(),
+            path: route.path(),
+            path_str: Cow::Owned(route.display().to_string()),
             use_authorization_token: true,
         }
     }
@@ -229,15 +270,13 @@ impl From<(Vec<u8>, Route)> for Request {
 
 impl From<(Form, Route)> for Request {
     fn from((form, route): (Form, Route)) -> Self {
-        let (method, path, path_str) = route.into_parts();
-
         Self {
             body: None,
             form: Some(form),
             headers: None,
-            method,
-            path,
-            path_str,
+            method: route.method(),
+            path: route.path(),
+            path_str: Cow::Owned(route.display().to_string()),
             use_authorization_token: true,
         }
     }
@@ -245,15 +284,13 @@ impl From<(Form, Route)> for Request {
 
 impl From<(Vec<u8>, Form, Route)> for Request {
     fn from((body, form, route): (Vec<u8>, Form, Route)) -> Self {
-        let (method, path, path_str) = route.into_parts();
-
         Self {
             body: Some(body),
             form: Some(form),
             headers: None,
-            method,
-            path,
-            path_str,
+            method: route.method(),
+            path: route.path(),
+            path_str: Cow::Owned(route.display().to_string()),
             use_authorization_token: true,
         }
     }
@@ -261,15 +298,13 @@ impl From<(Vec<u8>, Form, Route)> for Request {
 
 impl From<(HeaderMap<HeaderValue>, Route)> for Request {
     fn from((headers, route): (HeaderMap<HeaderValue>, Route)) -> Self {
-        let (method, path, path_str) = route.into_parts();
-
         Self {
             body: None,
             form: None,
             headers: Some(headers),
-            method,
-            path,
-            path_str,
+            method: route.method(),
+            path: route.path(),
+            path_str: Cow::Owned(route.display().to_string()),
             use_authorization_token: true,
         }
     }
@@ -277,15 +312,13 @@ impl From<(HeaderMap<HeaderValue>, Route)> for Request {
 
 impl From<(Vec<u8>, HeaderMap<HeaderValue>, Route)> for Request {
     fn from((body, headers, route): (Vec<u8>, HeaderMap<HeaderValue>, Route)) -> Self {
-        let (method, path, path_str) = route.into_parts();
-
         Self {
             body: Some(body),
             form: None,
             headers: Some(headers),
-            method,
-            path,
-            path_str,
+            method: route.method(),
+            path: route.path(),
+            path_str: Cow::Owned(route.display().to_string()),
             use_authorization_token: true,
         }
     }
@@ -293,16 +326,42 @@ impl From<(Vec<u8>, HeaderMap<HeaderValue>, Route)> for Request {
 
 impl From<(Form, HeaderMap<HeaderValue>, Route)> for Request {
     fn from((form, headers, route): (Form, HeaderMap<HeaderValue>, Route)) -> Self {
-        let (method, path, path_str) = route.into_parts();
-
         Self {
             body: None,
             form: Some(form),
             headers: Some(headers),
-            method,
-            path,
-            path_str,
+            method: route.method(),
+            path: route.path(),
+            path_str: Cow::Owned(route.display().to_string()),
             use_authorization_token: true,
         }
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::{super::Method, RequestBuilder};
+    use crate::routing::Path;
+    use static_assertions::assert_impl_all;
+    use std::{error::Error, fmt::Debug, str::FromStr};
+
+    assert_impl_all!(RequestBuilder: Debug, Send, Sync);
+
+    /// Test the default request values from [`RequestBuilder::raw`].
+    #[test]
+    fn test_builder_raw() -> Result<(), Box<dyn Error>> {
+        let path_and_query = "guilds".to_owned();
+        let path = Path::from_str(&path_and_query)?;
+
+        let builder = RequestBuilder::raw(Method::Post, path, path_and_query);
+        assert!(builder.0.body.is_none());
+        assert!(builder.0.form.is_none());
+        assert!(builder.0.headers.is_none());
+        assert_eq!(Method::Post, builder.0.method);
+        assert_eq!(Path::Guilds, builder.0.path);
+        assert_eq!("guilds", builder.0.path_str.as_ref());
+        assert!(builder.0.use_authorization_token);
+
+        Ok(())
+    }
+}
