@@ -1,4 +1,9 @@
-use crate::request::prelude::*;
+use crate::{
+    client::Client,
+    error::Error,
+    request::{Pending, Request},
+    routing::Route,
+};
 use twilight_model::user::Connection;
 
 /// Get the current user's connections.
@@ -14,7 +19,7 @@ impl<'a> GetCurrentUserConnections<'a> {
         Self { fut: None, http }
     }
 
-    fn start(&mut self) -> Result<()> {
+    fn start(&mut self) -> Result<(), Error> {
         let request = Request::from_route(Route::GetUserConnections);
 
         self.fut.replace(Box::pin(self.http.request(request)));
